# 数据接口 API 模块

本模块提供了数据标准和数据标签相关的所有API接口，包括创建、查询、更新、删除以及图谱生成功能。

## 主要功能

1. **数据标准操作**
   - 创建数据标准：支持添加数据标准及相关描述
   - 查询数据标准：支持分页查询、多条件筛选
   - 更新数据标准：修改数据标准的基本信息
   - 生成标准代码：根据标准描述和参数自动生成代码

2. **数据标签操作**
   - 创建数据标签：支持添加数据标签及相关描述
   - 查询数据标签：支持分页查询、多条件筛选
   - 动态识别标签分组：根据内容智能匹配相似的标签分组

3. **图谱生成**
   - 数据标准图谱：血缘关系、影响关系、全量关系
   - 数据标签图谱：血缘关系、影响关系

4. **关系管理**
   - 建立标准和标签之间的关系
   - 删除标签、标准、指标间的关系

## API接口列表

### 数据标准接口

- `/data/standard/add`：创建数据标准
- `/data/standard/detail`：获取数据标准详情
- `/data/standard/code`：生成数据标准代码
- `/data/standard/update`：更新数据标准
- `/data/standard/list`：查询数据标准列表
- `/data/standard/graph/all`：生成数据标准图谱

### 数据标签接口

- `/data/label/add`：创建数据标签
- `/data/label/detail`：获取数据标签详情
- `/data/label/list`：查询数据标签列表
- `/data/label/dynamic/identify`：动态识别标签分组
- `/data/label/graph/all`：生成数据标签图谱

### 关系管理接口

- `/metric/label/standard/delete`：删除节点间关系

## 使用示例

### 创建数据标准
```json
POST /data/standard/add
{
  "name": "用户ID格式标准",
  "category": "数据格式",
  "describe": "用户ID必须为16位数字，前8位为日期，后8位为流水号",
  "tag": ["用户", "ID", "格式"]
}
```

### 查询数据标签列表
```json
POST /data/label/list
{
  "current": 1,
  "size": 10,
  "name": "用户",
  "category": "业务标签",
  "group": "客户"
}
```

### 生成数据标准图谱
```json
POST /data/standard/graph/all
{
  "id": 123,
  "type": "all"
}
```

## 依赖关系

- 依赖核心业务逻辑模块 `app.core.data_interface`，提供数据标准和标签的业务处理功能
- 依赖图数据库服务 `neo4j_driver` 进行数据存储和查询
- 依赖元数据处理模块 `app.core.meta_data` 进行名称翻译和时间格式化
- 依赖LLM服务 `app.core.llm` 进行代码生成 