# 数据模型 API 接口模块

本模块提供了数据模型相关的所有API接口，包括数据模型的创建、查询、更新、删除以及各类数据模型图谱生成功能。

## 主要功能

1. **数据模型基础操作**
   - 创建数据模型：支持从数据资源、已有数据模型或DDL中创建数据模型
   - 查询数据模型：支持分页查询、多条件筛选
   - 更新数据模型：修改数据模型的基本信息和标签关系
   - 删除数据模型

2. **数据模型血缘关系**
   - 查询数据模型血缘关系
   - 获取数据资源间的血缘关系
   - 查询相关数据资源列表

3. **数据模型图谱生成**
   - 血缘关系图谱：展示数据模型与数据资源的血缘关系
   - 影响关系图谱：展示数据模型之间的使用关系
   - 全量关系图谱：展示数据模型的所有关系

## API接口列表

- `/model/data/relation`：数据模型血缘关系查询
- `/model/relatives/relation`：查询与指定数据资源有血缘关系的资源列表
- `/data/model/save`：保存从DDL中选取的数据模型
- `/model/data/search`：从数据资源中创建数据模型
- `/model/data/model/add`：从其他数据模型中创建数据模型
- `/data/model/detail`：获取数据模型详情
- `/data/model/delete`：删除数据模型
- `/data/model/list`：查询数据模型列表
- `/data/model/graph/all`：生成数据模型图谱
- `/data/model/list/graph`：生成数据模型列表图谱
- `/data/model/update`：更新数据模型信息

## 使用示例

### 创建数据模型
```json
POST /model/data/search
{
  "name": "客户信息模型",
  "en_name": "customer_info_model",
  "category": "业务模型",
  "description": "包含客户基本信息的数据模型",
  "tag": 123,
  "childrenId": [],
  "id_list": [
    {
      "resource_id": 456,
      "metaData": [
        {
          "id": 789,
          "data_standard": "GB/T 22240-2008",
          "data_name": "客户ID"
        }
      ]
    }
  ]
}
```

### 查询数据模型列表
```json
POST /data/model/list
{
  "current": 1,
  "size": 10,
  "name": "客户",
  "category": "业务模型",
  "tag": 123,
  "level": 1
}
```

## 依赖关系

- 依赖核心业务逻辑模块 `app.core.data_model`，提供数据模型的业务处理功能
- 依赖图数据库服务 `neo4j_driver` 进行数据存储和查询
- 依赖元数据处理模块 `app.core.meta_data` 进行模型元数据解析 