# LLM服务模块

本模块提供了大语言模型相关的功能接口，用于支持系统中的智能代码生成、文本分析等功能。

## 功能概述

- **LLM基础调用服务**：提供与大语言模型通信的基础功能
- **代码生成服务**：提供基于LLM的代码自动生成功能

## 主要功能

### LLM基础服务 (llm_service.py)

- **llm_client(content)**：调用LLM服务进行内容生成，传入提示内容，返回模型响应

### 代码生成服务 (code_generation.py)

- **code_generate_standard(describe, relation)**：根据描述和参数关系生成标准化代码

## 使用示例

```python
# 调用LLM生成内容
from app.core.llm import llm_client

content = "将以下中文专业术语翻译成英文: 数据治理"
result = llm_client(content)
print(result)  # 输出: Data Governance

# 生成数据标准相关代码
from app.core.llm import code_generate_standard

describe = "计算两个数的和"
relation = {
    "输入参数": "a: int, b: int",
    "输出参数": "sum: int"
}
code = code_generate_standard(describe, relation)
print(code)
```

## 配置说明

LLM服务使用以下配置参数：

- **api_key**: LLM服务的API密钥
- **base_url**: API服务地址
- **model_name**: 使用的模型名称

在生产环境中，建议将这些参数移至环境变量或配置文件中。

## 依赖说明

- 需要安装`openai`包
- 依赖标准Python日志模块 