# 生产线核心功能模块

本模块包含生产线相关的核心业务逻辑功能实现。

## 功能概述

生产线核心模块主要负责数据模型、数据资源和数据指标之间的关系构建与可视化，提供图形化展示和处理功能。

## 主要功能

### 生产线图谱绘制 (production_draw_graph)

根据节点ID和类型绘制生产线图谱，支持以下三种类型的节点：
- 数据模型(data_model)：处理数据模型与元数据节点及数据标准之间的关系
- 数据资源(data_resource)：处理数据资源与元数据节点及数据标准之间的关系
- 数据指标(data_metric)：处理数据指标与元数据节点之间的关系

## 技术实现

本模块主要使用Neo4j图数据库进行数据关系的查询与处理，通过Cypher查询语言构建复杂的图谱关系。主要关系类型包括：

- connection：连接关系
- clean_model：模型清洗关系
- clean_resource：资源清洗关系

## 使用方法

```python
from app.core.production_line import production_draw_graph

# 获取数据模型的图谱
graph_data = production_draw_graph(model_id, "data_model")

# 获取数据资源的图谱
graph_data = production_draw_graph(resource_id, "data_resource")

# 获取数据指标的图谱
graph_data = production_draw_graph(metric_id, "data_metric")
```

## 返回数据结构

图谱数据的格式为：

```python
{
    "nodes": [
        {"id": "节点ID", "text": "节点名称", "type": "节点类型"},
        # 更多节点...
    ],
    "lines": [
        {"from": "起始节点ID", "to": "目标节点ID", "text": "关系描述"},
        # 更多连线...
    ],
    "rootId": "根节点ID"
}
``` 