#!/usr/bin/env python
"""
数据库初始化脚本
创建用户表和相关索引
"""

import os
import sys
import logging

# 添加项目根目录到Python路径
sys.path.insert(0, os.path.abspath(os.path.join(os.path.dirname(__file__), '..')))

from app.core.system.auth import init_db

# 配置日志
logging.basicConfig(
    level=logging.INFO,
    format='%(asctime)s - %(name)s - %(levelname)s - %(message)s'
)
logger = logging.getLogger(__name__)

def init_database():
    """
    初始化数据库，创建必要的表和索引
    """
    logger.info("开始初始化数据库...")
    
    # 初始化用户表
    if init_db():
        logger.info("用户表初始化成功")
    else:
        logger.error("用户表初始化失败")
    
    # 可以在这里添加其他表的初始化
    
    logger.info("数据库初始化完成")

if __name__ == "__main__":
    try:
        init_database()
    except Exception as e:
        logger.error(f"数据库初始化失败: {str(e)}")
        sys.exit(1)
    
    sys.exit(0) 